@@ -1,5 +1,5 @@
 /* window.c -- windows in Info.
-   $Id: window.c,v 1.14 2008/06/11 09:55:43 gray Exp $
+   $Id: window.c,v 1.16 2008/06/28 08:09:49 gray Exp $
 
    Copyright (C) 1993, 1997, 1998, 2001, 2002, 2003, 2004, 2007, 2008
    Free Software Foundation, Inc.
@@ -46,6 +46,9 @@ WINDOW *active_window = NULL;
    to the entire screen. */
 #define echo_area_required (1 + the_echo_area->height)
 
+/* Show malformed multibyte sequences */
+int show_malformed_multibyte_p = 0;
+
 /* Initalize the window system by creating THE_SCREEN and THE_ECHO_AREA.
    Create the first window ever.
    You pass the dimensions of the total screen size. */
@@ -1596,7 +1599,7 @@ process_node_text (WINDOW *win, char *start,
             }
 	  else if (ansi_escape (iter, &cur_len))
 	    {
-	      replen = 1;
+	      replen = 0;
 	      ITER_SETBYTES (iter, cur_len);
 	    }
 	  else if (info_tag (iter, do_tags, &cur_len)) 
@@ -1613,7 +1616,7 @@ process_node_text (WINDOW *win, char *start,
 	      replen = cur_len;
             }
         }
-      else
+      else if (show_malformed_multibyte_p || mbi_cur (iter).wc_valid)
 	{
 	  /* FIXME: I'm not sure it's the best way to deal with unprintable
 	     multibyte characters */
@@ -1737,6 +1740,51 @@ process_node_text (WINDOW *win, char *start,
   return line_index;
 }
 
+void
+clean_manpage (char *manpage)
+{
+  mbi_iterator_t iter;
+  size_t len = strlen (manpage);
+  char *newpage = xmalloc (len + 1);
+  char *np = newpage;
+  int prev_len = 0;
+  
+  for (mbi_init (iter, manpage, len);
+       mbi_avail (iter);
+       mbi_advance (iter))
+    {
+      const char *cur_ptr = mbi_cur_ptr (iter);
+      int cur_len = mb_len (mbi_cur (iter));
+
+      if (cur_len == 1)
+	{
+	  if (*cur_ptr == '\b' || *cur_ptr == '\f')
+	    {
+	      if (np >= newpage + prev_len)
+		np -= prev_len;
+	    }
+	  else if (ansi_escape (iter, &cur_len))
+	    {
+	      memcpy (np, cur_ptr, cur_len);
+	      np += cur_len;
+	      ITER_SETBYTES (iter, cur_len);
+	    }
+	  else if (show_malformed_multibyte_p || mbi_cur (iter).wc_valid)
+	    *np++ = *cur_ptr;
+	}
+      else
+	{
+	  memcpy (np, cur_ptr, cur_len);
+	  np += cur_len;
+	}
+      prev_len = cur_len;
+    }
+  *np = 0;
+  
+  strcpy (manpage, newpage);
+  free (newpage);
+}
+
 static void
 line_map_init (LINE_MAP *map, int line)
 {
