@@ -1,5 +1,5 @@
 /* window.h -- Structure and flags used in manipulating Info windows.
-   $Id: window.h,v 1.9 2008/06/10 11:37:47 gray Exp $
+   $Id: window.h,v 1.11 2008/06/28 08:10:02 gray Exp $
 
    This file is part of GNU Info, a program for reading online documentation
    stored in Info format.
@@ -107,6 +107,8 @@ extern WINDOW *active_window;   /* The currently active window. */
 extern WINDOW *the_screen;      /* The Info screen is just another window. */
 extern WINDOW *the_echo_area;   /* THE_ECHO_AREA is a window in THE_SCREEN. */
 
+extern int show_malformed_multibyte_p; /* Show malformed multibyte sequences */
+
 /* Global variable control redisplay of scrolled windows.  If non-zero, it
    is the desired number of lines to scroll the window in order to make
    point visible.  A user might set this to 1 for smooth scrolling.  If
@@ -254,6 +256,8 @@ extern size_t process_node_text
          int (*fun) (void *, size_t, const char *, char *, size_t, size_t),
 	 void *closure);
 
+void clean_manpage (char *manpage);
+
 extern void window_compute_line_map (WINDOW *win);
 
 int window_point_to_column (WINDOW *win, long point, long *np);
